@@ -1,6 +1,6 @@
 from __future__ import absolute_import
 
-VERSION = (1, 6, 0)
+VERSION = (5, 4, 0)
 __version__ = VERSION
 __versionstr__ = '.'.join(map(str, VERSION))
 
@@ -20,6 +20,6 @@ from .connection_pool import ConnectionPool, ConnectionSelector, \
     RoundRobinSelector
 from .serializer import JSONSerializer
 from .connection import Connection, RequestsHttpConnection, \
-    Urllib3HttpConnection, MemcachedConnection, ThriftConnection
+    Urllib3HttpConnection
 from .exceptions import *
 
